summaryrefslogtreecommitdiffstats
path: root/chrome/test/functional
diff options
context:
space:
mode:
authornirnimesh@chromium.org <nirnimesh@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-01-05 01:16:47 +0000
committernirnimesh@chromium.org <nirnimesh@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-01-05 01:16:47 +0000
commit783ffc7355af267f7dd6881f9f2436fbcd95b2a1 (patch)
treeffa51a24f071f870e66f734ab8b8eed1c2d0822f /chrome/test/functional
parentf235bfdb36fbc782356fba6c7e36cc139dc816e5 (diff)
downloadchromium_src-783ffc7355af267f7dd6881f9f2436fbcd95b2a1.zip
chromium_src-783ffc7355af267f7dd6881f9f2436fbcd95b2a1.tar.gz
chromium_src-783ffc7355af267f7dd6881f9f2436fbcd95b2a1.tar.bz2
Omnibox recent page history test fix for timeout problem
Review URL: http://codereview.chromium.org/5960010 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@70473 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/test/functional')
-rw-r--r--chrome/test/functional/omnibox.py7
1 files changed, 4 insertions, 3 deletions
diff --git a/chrome/test/functional/omnibox.py b/chrome/test/functional/omnibox.py
index fa716ca..31912e0 100644
--- a/chrome/test/functional/omnibox.py
+++ b/chrome/test/functional/omnibox.py
@@ -315,12 +315,13 @@ class OmniboxTest(pyauto.PyUITest):
for site in sites:
self.NavigateToURL(self.GetFileURLForPath(site))
old_matches = self._GetOmniboxMatchesFor(search_text)
# Using max timeout as 60 seconds, since expected page only shows up
# after 60 seconds and default timeout is less than that.
# TODO (Nirnimesh): design an api using which we can push history changes to
# omnibox results.
self.assertTrue(self.WaitUntil(
- lambda: self._GotNewMatches(len(old_matches), search_text), timeout=60))
+ lambda: self._GotNewMatches(len(old_matches), search_text),
+ timeout=120))
matches = self._GetOmniboxMatchesFor(search_text)
matches_description = [x for x in matches if x['type'] ==
'open-history-page']
@@ -315,12 +315,13 @@ class OmniboxTest(pyauto.PyUITest):
self.NavigateToURL(self.GetFileURLForPath(site))
old_matches = self._GetOmniboxMatchesFor(search_text)
- # Using max timeout as 60 seconds, since expected page only shows up
- # after 60 seconds and default timeout is less than that.
+ # Using max timeout as 120 seconds, since expected page only shows up
+ # after > 60 seconds on some machines and default timeout is less than that.
# TODO (Nirnimesh): design an api using which we can push history changes to
# omnibox results.